#!/bin/bash
# 获取本机ip 192 ip
HOST_IP=$(hostname -I | grep -E "192\.168\.[0-9]+\.[0-9]+" -o)
OS_IS_LINUX='yes'
if [ $(uname -o) != "GNU/Linux" ]; then OS_IS_LINUX='no'; fi
DOCKER_YES='yes'
if [ ! $(command -v docker) ]; then DOCKER_YES='no'; fi
GIT_YES='yes'
if [ ! $(command -v git) ]; then DOCKER_YES='no'; fi
TAR_YES='yes'
if [ ! $(command -v tar) ]; then DOCKER_YES='no'; fi
AVAILABLE_MEMORY=$(free -m | awk 'NR==2{print $7}')
COMPOSE_CMD='docker-compose'
if docker --help | grep compose >/dev/null; then
  COMPOSE_CMD='docker compose'
fi
DOCKER_COMPOSE_YES='yes'
if [ ! $(command -v docker-compose) ] && [ "$COMPOSE_CMD" != 'docker compose' ]; then DOCKER_COMPOSE_YES='no'; fi
PORT_YES='yes'
if ss -tpl | grep -E '8118|8181' >/dev/null; then PORT_YES='no'; fi
cat <<EOF
检查环境:
1. 是否是linux系统 $OS_IS_LINUX
2. docker $DOCKER_YES
3. git $GIT_YES
4. docker-compose/docker compose $DOCKER_COMPOSE_YES
5. tar $TAR_YES
6. 端口8118，8181是否可用 $PORT_YES
8. 本机IP $HOST_IP
EOF
if echo "$TAR_YES$GIT_YES$DOCKER_COMPOSE_YES$OS_IS_LINUX$DOCKER_YES$PORT_YES" | grep no >/dev/null; then
  exit
fi
# 变量声明
ENV='dev'
CODE_DIR=$(pwd)/code-$ENV
for arg in "$@"; do
  if [ -n "$arg" ]; then
    ENV="$arg"
    break
  fi
done

BUILD_DIR=galaxy-$ENV
if [ ! -d $CODE_DIR ]; then
  mkdir -p $CODE_DIR
fi
cd $CODE_DIR
echo "下载demo代码"
curl -o data.tgz -# http://192.168.11.163/demo/code-demo-920.tgz
echo '解压缩(每1000个文件输出一个.)'
tar --checkpoint=.1000 --checkpoint-action=dot --strip-components=1 -xf data.tgz
rm -f data.tgz
echo 'storage 目录权限处理'
find ./ -type d -name 'storage' -exec chmod -R 0777 {} +
cd $CODE_DIR/crm
grep -rlZ 192.168.11.163 ./ | xargs -0 sed -i "s/192.168.11.163/$HOST_IP/g"
cd $CODE_DIR/dwp/main
grep -rlZ 192.168.11.163 ./ | xargs -0 sed -i "s/192.168.11.163/$HOST_IP/g"
cd $CODE_DIR/../
git clone http://gitlab.galaxy-immi.com/kunkka.wh/docker-test.git $BUILD_DIR
cd $BUILD_DIR
cat <<EOF >.env
# 环境变量env dev,test,test1,test2等区分
ENV=$ENV
# 服务宿主机的端口
PORT=8118
PORT_CRM=8181
# 代码目录,含前后端
CODE_DIR=$CODE_DIR
JAVA_PROFILE=innerdev # java需要根据环境调整
#nacos 客户端轮询间隔
TICK_TIME=30000
EOF
echo '生成.env文件'
cat .env
echo '启动容器,检查端口是否占用'
$COMPOSE_CMD up -d

cat <<EOF
本地访问地址
http://$HOST_IP:8118/   DWP
http://$HOST_IP:8181/   CRM
安装完成！
EOF
